# regridding

![tests](https://github.com/sun-data/regridding/actions/workflows/tests.yml/badge.svg)
[![codecov](https://codecov.io/gh/sun-data/regridding/graph/badge.svg?token=8W5I2EBDDX)](https://codecov.io/gh/sun-data/regridding)
[![Documentation Status](https://readthedocs.org/projects/regridding/badge/?version=latest)](https://regridding.readthedocs.io/en/latest/?badge=latest)
[![PyPI version](https://badge.fury.io/py/regridding.svg)](https://badge.fury.io/py/regridding)

Numba-accelerated multilinear and first-order conservative interpolation of Numpy arrays.
